@@ -31,6 +31,11 @@ class Enviar(object):
             return SituacaoPedido.SITUACAO_PEDIDO_PAGO
         return SituacaoPedido.SITUACAO_PEDIDO_CANCELADO
 
+    #FIXME: rever isso ao refatorar o sistema de pedido
+    @property
+    def valor_envio(self):
+        return self.pedido.valor_total - self.pedido.valor_subtotal
+
 
 class EnviarPedido(Plugavel):
     def __init__(self, pedido_numero, dados, conta_id, configuracao_pagamento):
